@@ -141,8 +141,8 @@ check_end_t_arg <- function(len, ...) {
         stop("'end_t1' must be greater than or equal to '0'")
     if (!all(arg$end_t1 < arg$end_t2))
         stop("'end_t1' must be less than 'end_t2'")
-    if (!all(arg$end_t2 < arg$end_t3))
-        stop("'end_t2' must be less than 'end_t3'")
+    if (!all((arg$end_t4 < arg$end_t1) | (arg$end_t2 < arg$end_t3)))
+        stop("'end_t2' must be less than 'end_t3' or 'end_t3' less than 'end_t1'")
     if (!all(arg$end_t3 < 364))
         stop("'end_t3' must be less than '364'")
     if (!all(0 <= arg$end_t4))
