@@ -1115,7 +1115,10 @@ model <- SISe(u0      = u0,
               end_t3  = 273,
               end_t4  = 365,
               epsilon = 0.000011)
-model@gdata <- rep(Inf, length(model@gdata))
+model@gdata["beta_t1"] <- Inf
+model@gdata["beta_t2"] <- Inf
+model@gdata["beta_t3"] <- Inf
+model@gdata["beta_t4"] <- Inf
 res <- tools::assertError(run(model, threads = 1))
 stopifnot(length(grep("The continuous state 'v' is not finite.",
                       res[[1]]$message)) > 0)
@@ -1140,3 +1143,7 @@ model <- SISe(u0      = u0,
 res <- tools::assertError(run(model, threads = 1))
 stopifnot(length(grep("The continuous state 'v' is negative.",
                       res[[1]]$message)) > 0)
+
+## Check data
+stopifnot(identical(nrow(events_SISe()), 466692L))
+stopifnot(identical(nrow(u0_SISe()), 1600L))
