@@ -1135,7 +1135,10 @@ model <- SISe_sp(u0       = u0,
                  end_t4   = 365,
                  coupling = 0.0005,
                  distance = distance)
-model@gdata <- rep(Inf, length(model@gdata))
+model@gdata["beta_t1"] <- Inf
+model@gdata["beta_t2"] <- Inf
+model@gdata["beta_t3"] <- Inf
+model@gdata["beta_t4"] <- Inf
 res <- tools::assertError(run(model, threads = 1))
 stopifnot(length(grep("The continuous state 'v' is not finite.",
                       res[[1]]$message)) > 0)
